# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/long_tx_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ydb/core/protos/long_tx_service.proto\x12\x14NKikimrLongTxService\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\"Y\n\tTLongTxId\x12\x10\n\x08UniqueId\x18\x01 \x01(\x0c\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\x12\x14\n\x0cSnapshotStep\x18\x03 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\x04 \x01(\x04\"\xb5\x01\n\nTEvBeginTx\x12\x14\n\x0c\x44\x61tabaseName\x18\x01 \x01(\t\x12\x34\n\x04Mode\x18\x02 \x01(\x0e\x32&.NKikimrLongTxService.TEvBeginTx.EMode\"[\n\x05\x45Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x12\n\x0eMODE_READ_ONLY\x10\x01\x12\x13\n\x0fMODE_WRITE_ONLY\x10\x02\x12\x13\n\x0fMODE_READ_WRITE\x10\x03\"\x99\x01\n\x10TEvBeginTxResult\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x31\n\x08LongTxId\x18\x03 \x01(\x0b\x32\x1f.NKikimrLongTxService.TLongTxId\"@\n\x0bTEvCommitTx\x12\x31\n\x08LongTxId\x18\x01 \x01(\x0b\x32\x1f.NKikimrLongTxService.TLongTxId\"g\n\x11TEvCommitTxResult\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"B\n\rTEvRollbackTx\x12\x31\n\x08LongTxId\x18\x01 \x01(\x0b\x32\x1f.NKikimrLongTxService.TLongTxId\"i\n\x13TEvRollbackTxResult\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"\xc8\x01\n\x1aTEvAttachColumnShardWrites\x12\x31\n\x08LongTxId\x18\x01 \x01(\x0b\x32\x1f.NKikimrLongTxService.TLongTxId\x12G\n\x06Writes\x18\x02 \x03(\x0b\x32\x37.NKikimrLongTxService.TEvAttachColumnShardWrites.TWrite\x1a.\n\x06TWrite\x12\x13\n\x0b\x43olumnShard\x18\x01 \x01(\x04\x12\x0f\n\x07WriteId\x18\x02 \x01(\x04\"v\n TEvAttachColumnShardWritesResult\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\".\n\x16TEvAcquireReadSnapshot\x12\x14\n\x0c\x44\x61tabaseName\x18\x01 \x01(\t\"\xb4\x01\n\x1cTEvAcquireReadSnapshotResult\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x14\n\x0cSnapshotStep\x18\x03 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\x04 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x05 \x01(\t\"4\n\x10TEvSubscribeLock\x12\x0e\n\x06LockId\x18\x01 \x01(\x04\x12\x10\n\x08LockNode\x18\x02 \x01(\r\"\xd6\x01\n\rTEvLockStatus\x12\x0e\n\x06LockId\x18\x01 \x01(\x04\x12\x10\n\x08LockNode\x18\x02 \x01(\r\x12;\n\x06Status\x18\x03 \x01(\x0e\x32+.NKikimrLongTxService.TEvLockStatus.EStatus\"f\n\x07\x45Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11STATUS_SUBSCRIBED\x10\x01\x12\x14\n\x10STATUS_NOT_FOUND\x10\x02\x12\x16\n\x12STATUS_UNAVAILABLE\x10\x03\"6\n\x12TEvUnsubscribeLock\x12\x0e\n\x06LockId\x18\x01 \x01(\x04\x12\x10\n\x08LockNode\x18\x02 \x01(\rB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.long_tx_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TLONGTXID._serialized_start=156
  _TLONGTXID._serialized_end=245
  _TEVBEGINTX._serialized_start=248
  _TEVBEGINTX._serialized_end=429
  _TEVBEGINTX_EMODE._serialized_start=338
  _TEVBEGINTX_EMODE._serialized_end=429
  _TEVBEGINTXRESULT._serialized_start=432
  _TEVBEGINTXRESULT._serialized_end=585
  _TEVCOMMITTX._serialized_start=587
  _TEVCOMMITTX._serialized_end=651
  _TEVCOMMITTXRESULT._serialized_start=653
  _TEVCOMMITTXRESULT._serialized_end=756
  _TEVROLLBACKTX._serialized_start=758
  _TEVROLLBACKTX._serialized_end=824
  _TEVROLLBACKTXRESULT._serialized_start=826
  _TEVROLLBACKTXRESULT._serialized_end=931
  _TEVATTACHCOLUMNSHARDWRITES._serialized_start=934
  _TEVATTACHCOLUMNSHARDWRITES._serialized_end=1134
  _TEVATTACHCOLUMNSHARDWRITES_TWRITE._serialized_start=1088
  _TEVATTACHCOLUMNSHARDWRITES_TWRITE._serialized_end=1134
  _TEVATTACHCOLUMNSHARDWRITESRESULT._serialized_start=1136
  _TEVATTACHCOLUMNSHARDWRITESRESULT._serialized_end=1254
  _TEVACQUIREREADSNAPSHOT._serialized_start=1256
  _TEVACQUIREREADSNAPSHOT._serialized_end=1302
  _TEVACQUIREREADSNAPSHOTRESULT._serialized_start=1305
  _TEVACQUIREREADSNAPSHOTRESULT._serialized_end=1485
  _TEVSUBSCRIBELOCK._serialized_start=1487
  _TEVSUBSCRIBELOCK._serialized_end=1539
  _TEVLOCKSTATUS._serialized_start=1542
  _TEVLOCKSTATUS._serialized_end=1756
  _TEVLOCKSTATUS_ESTATUS._serialized_start=1654
  _TEVLOCKSTATUS_ESTATUS._serialized_end=1756
  _TEVUNSUBSCRIBELOCK._serialized_start=1758
  _TEVUNSUBSCRIBELOCK._serialized_end=1812
# @@protoc_insertion_point(module_scope)



import ydb.apps.dstool.lib.dstool_cmd_pdisk_add_by_serial as pdisk_add_by_serial
import ydb.apps.dstool.lib.dstool_cmd_pdisk_remove_by_serial as pdisk_remove_by_serial
import ydb.apps.dstool.lib.dstool_cmd_pdisk_set as pdisk_set
import ydb.apps.dstool.lib.dstool_cmd_pdisk_list as pdisk_list

import ydb.apps.dstool.lib.dstool_cmd_vdisk_remove_donor as vdisk_remove_donor
import ydb.apps.dstool.lib.dstool_cmd_vdisk_evict as vdisk_evict
import ydb.apps.dstool.lib.dstool_cmd_vdisk_list as vdisk_list
import ydb.apps.dstool.lib.dstool_cmd_vdisk_wipe as vdisk_wipe

import ydb.apps.dstool.lib.dstool_cmd_group_add as group_add
import ydb.apps.dstool.lib.dstool_cmd_group_check as group_check
import ydb.apps.dstool.lib.dstool_cmd_group_list as group_list
import ydb.apps.dstool.lib.dstool_cmd_group_show_blob_info as group_show_blob_info
import ydb.apps.dstool.lib.dstool_cmd_group_show_usage_by_tablets as group_show_usage_by_tablets
import ydb.apps.dstool.lib.dstool_cmd_group_state as group_state
import ydb.apps.dstool.lib.dstool_cmd_group_take_snapshot as group_take_snapshot

import ydb.apps.dstool.lib.dstool_cmd_pool_list as pool_list

import ydb.apps.dstool.lib.dstool_cmd_box_list as box_list

import ydb.apps.dstool.lib.dstool_cmd_node_list as node_list

import ydb.apps.dstool.lib.dstool_cmd_cluster_balance as cluster_balance
import ydb.apps.dstool.lib.dstool_cmd_cluster_list as cluster_list
import ydb.apps.dstool.lib.dstool_cmd_cluster_get as cluster_get
import ydb.apps.dstool.lib.dstool_cmd_cluster_set as cluster_set
import ydb.apps.dstool.lib.dstool_cmd_cluster_workload_run as cluster_workload_run

import sys
import ydb.apps.dstool.lib.common as common

MODULE_PREFIX = 'ydb.apps.dstool.lib.dstool_cmd_'

modules = [
    cluster_balance, cluster_get, cluster_set, cluster_list, cluster_workload_run,
    node_list,
    box_list,
    pool_list,
    group_check, group_show_blob_info, group_show_usage_by_tablets, group_state, group_take_snapshot, group_add, group_list,
    pdisk_add_by_serial, pdisk_remove_by_serial, pdisk_set, pdisk_list,
    vdisk_remove_donor, vdisk_evict, vdisk_list, vdisk_wipe,
]

default_structure = [
    ('pdisk', ['add-by-serial', 'remove-by-serial', 'set', 'list']),
    ('vdisk', ['evict', 'remove-donor', 'wipe', 'list']),
    ('group', ['add', 'check', ('show', ['blob-info', 'usage-by-tablets']), 'state', 'take-snapshot', 'list']),
    ('pool', ['list']),
    ('box', ['list']),
    ('node', ['list']),
    ('cluster', ['balance', 'get', 'set', ('workload', ['run']), 'list']),
]


def make_command_map_by_structure(subparsers, modules=modules, structure=default_structure):
    module_map = {}
    for module in modules:
        module_map[module.__name__[len(MODULE_PREFIX):].replace('_', '-')] = module

    command_map = {}

    already_added = set()

    def add_commands_by_structue(struct, subparsers, prefix=''):
        nonlocal command_map
        for el in struct:
            if isinstance(el, tuple):
                def namespace_barrier():
                    parser = subparsers.add_parser(el[0])
                    group_name = prefix + el[0]
                    command_group_name = group_name.replace('_', '-')
                    new_prefix = group_name + '_'
                    new_prefix_for_command = new_prefix.replace('_', '-')
                    command_dest = new_prefix + 'command'
                    new_subparsers = parser.add_subparsers(dest=command_dest, required=True)
                    add_commands_by_structue(el[1], new_subparsers, new_prefix)
                    command_map[command_group_name] = lambda args: command_map[new_prefix_for_command + getattr(args, command_dest)](args)
                namespace_barrier()
            elif isinstance(el, str):
                def namespace_barrier():
                    command_name = prefix + el
                    key = command_name.replace('_', '-')
                    already_added.add(key)
                    if key in module_map:
                        module = module_map[key]
                        if 'help' in module.__dict__:
                            help = module.help
                        else:
                            help = module.description
                        module.add_options(subparsers.add_parser(el, help=help, description=module.description))
                        command_map[key] = module.do
                    else:
                        subparsers.add_parser(el, help='UNIMPLEMETED')
                namespace_barrier()
    add_commands_by_structue(structure, subparsers)

    for cmd_name in sorted(set(module_map) - already_added):
        module = module_map[cmd_name]
        module.add_options(subparsers.add_parser(cmd_name, help=module.description))
        command_map[cmd_name] = module.do

    return command_map


class TerminationOutput:
    def __init__(self):
        self._lines = []
        self._hint_lines = []

    def add_line(self, line):
        self._lines.append(line)

    def add_hint_line(self, line):
        self._hint_lines.append(line)

    def print_json(self):
        common.print_json_result('error', '\n'.join(self._lines))

    def print_pretty(self):
        for line in self._lines:
            print(line, file=sys.stderr)
        for line in self._hint_lines:
            print(line, file=sys.stderr)

    def print(self, args):
        if getattr(args, 'format', None) == 'json':
            self.print_json()
        else:
            self.print_pretty()


def run_command(command_map, args):
    output = TerminationOutput()
    try:
        command_map.get(args.global_command)(args)
    except common.ConnectionError as ex:
        output.add_line('Connection Error: {}'.format(ex))
        if common.connection_params.quiet:
            output.add_hint_line("Remove '--quiet' to see more information")
        output.print(args)
        sys.exit(1)
    except common.QueryError as ex:
        output.add_line('Query Error: {}'.format(ex))
        if common.connection_params.quiet:
            output.add_hint_line("Use '--verbose' to see more information")
        output.print(args)
        sys.exit(1)
    except common.GroupSelectionError as ex:
        output.add_line('Group Selection Error: {}'.format(ex))
        output.print(args)
        sys.exit(1)
    except Exception as ex:
        output.add_line('Unexpected Error: {}'.format(ex))
        output.print(args)
        raise
        sys.exit(1)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/persqueue_error_codes_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4ydb/public/api/protos/persqueue_error_codes_v1.proto\x12\x17Ydb.PersQueue.ErrorCode*\x86\x05\n\tErrorCode\x12\x06\n\x02OK\x10\x00\x12\x12\n\x0cINITIALIZING\x10\xa1\xc2\x1e\x12\x0e\n\x08OVERLOAD\x10\xa2\xc2\x1e\x12\x11\n\x0b\x42\x41\x44_REQUEST\x10\xa3\xc2\x1e\x12\x12\n\x0cWRONG_COOKIE\x10\xa4\xc2\x1e\x12\x16\n\x10SOURCEID_DELETED\x10\xb8\xc2\x1e\x12#\n\x1dWRITE_ERROR_PARTITION_IS_FULL\x10\xa5\xc2\x1e\x12\x1e\n\x18WRITE_ERROR_DISK_IS_FULL\x10\xaf\xc2\x1e\x12\x1c\n\x16WRITE_ERROR_BAD_OFFSET\x10\xb3\xc2\x1e\x12#\n\x1d\x43REATE_SESSION_ALREADY_LOCKED\x10\xa6\xc2\x1e\x12\x1f\n\x19\x44\x45LETE_SESSION_NO_SESSION\x10\xa7\xc2\x1e\x12\x1c\n\x16READ_ERROR_IN_PROGRESS\x10\xa8\xc2\x1e\x12\x1b\n\x15READ_ERROR_NO_SESSION\x10\xa9\xc2\x1e\x12!\n\x1bREAD_ERROR_TOO_SMALL_OFFSET\x10\xab\xc2\x1e\x12\x1f\n\x19READ_ERROR_TOO_BIG_OFFSET\x10\xac\xc2\x1e\x12\'\n!SET_OFFSET_ERROR_COMMIT_TO_FUTURE\x10\xad\xc2\x1e\x12\x17\n\x11TABLET_IS_DROPPED\x10\xae\xc2\x1e\x12\x13\n\rREAD_NOT_DONE\x10\xb0\xc2\x1e\x12\x13\n\rUNKNOWN_TOPIC\x10\xb1\xc2\x1e\x12\x13\n\rACCESS_DENIED\x10\xb2\xc2\x1e\x12\x16\n\x10\x43LUSTER_DISABLED\x10\xb4\xc2\x1e\x12\x1c\n\x16WRONG_PARTITION_NUMBER\x10\xb5\xc2\x1e\x12\"\n\x1cPREFERRED_CLUSTER_MISMATCHED\x10\xb6\xc2\x1e\x12\x0b\n\x05\x45RROR\x10\x84\xc3\x1e\x42$\n\"com.yandex.ydb.persqueue.errorcodeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.persqueue_error_codes_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.yandex.ydb.persqueue.errorcode'
  _ERRORCODE._serialized_start=82
  _ERRORCODE._serialized_end=728
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_pdisk_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ydb/core/protos/blobstorage_pdisk_config.proto\x12\x12NKikimrBlobStorage\"\x97\x08\n\x0cTPDiskConfig\x12\"\n\x1aStatisticsUpdateIntervalMs\x18\x64 \x01(\x04\x12\x1c\n\x14\x42ytesSchedulerWeight\x18i \x01(\x04\x12\x11\n\tLogWeight\x18k \x01(\x04\x12\x13\n\x0b\x46reshWeight\x18l \x01(\x04\x12\x12\n\nCompWeight\x18m \x01(\x04\x12\x15\n\rSyncLogWeight\x18n \x01(\x04\x12\x12\n\nHugeWeight\x18o \x01(\x04\x12\x16\n\x0e\x46\x61stReadWeight\x18p \x01(\x04\x12\x17\n\x0fOtherReadWeight\x18q \x01(\x04\x12\x12\n\nLoadWeight\x18r \x01(\x04\x12\x15\n\rLowReadWeight\x18x \x01(\x04\x12\x19\n\x11MinLogChunksTotal\x18\x01 \x01(\x04\x12&\n\x1eMaxLogChunksPerOwnerMultiplier\x18\x02 \x01(\x04\x12#\n\x1bMaxLogChunksPerOwnerDivisor\x18\x03 \x01(\x04\x12\x1e\n\x16SortFreeChunksPerItems\x18\x04 \x01(\x04\x12\x12\n\nSectorSize\x18\x06 \x01(\r\x12\x11\n\tChunkSize\x18\x07 \x01(\r\x12\x45\n\x12GetDriveDataSwitch\x18\xe8\x07 \x01(\x0e\x32(.NKikimrBlobStorage.TPDiskConfig.ESwitch\x12\x43\n\x10WriteCacheSwitch\x18\xe9\x07 \x01(\x0e\x32(.NKikimrBlobStorage.TPDiskConfig.ESwitch\x12\x1d\n\x14\x44riveModelSeekTimeNs\x18\xed\x07 \x01(\x04\x12\x1b\n\x12\x44riveModelSpeedBps\x18\xee\x07 \x01(\x04\x12$\n\x1b\x44riveModelBulkWrieBlockSize\x18\xf0\x07 \x01(\x04\x12\x1f\n\x16\x44riveModelTrimSpeedBps\x18\xf1\x07 \x01(\x04\x12\x15\n\x0cReorderingMs\x18\xf3\x07 \x01(\x04\x12\x14\n\x0b\x43ostLimitNs\x18\xfe\x07 \x01(\x04\x12\x17\n\x0e\x44\x65viceInFlight\x18\xff\x07 \x01(\x04\x12\"\n\x19\x42ufferPoolBufferSizeBytes\x18\x80\x08 \x01(\r\x12\x1e\n\x15\x42ufferPoolBufferCount\x18\x81\x08 \x01(\r\x12#\n\x1aMaxQueuedCompletionActions\x18\x82\x08 \x01(\r\x12\"\n\x19InsaneLogChunksMultiplier\x18\xd0\x0f \x01(\x04\x12\x1a\n\x11\x45xpectedSlotCount\x18\xd1\x0f \x01(\x04\"U\n\x07\x45Switch\x12\x0e\n\nDoNotTouch\x10\x00\x12\n\n\x06\x45nable\x10\x01\x12\x0f\n\x0b\x46orceEnable\x10\x02\x12\x0b\n\x07\x44isable\x10\x03\x12\x10\n\x0c\x46orceDisable\x10\x04\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_pdisk_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TPDISKCONFIG._serialized_start=71
  _TPDISKCONFIG._serialized_end=1118
  _TPDISKCONFIG_ESWITCH._serialized_start=1033
  _TPDISKCONFIG_ESWITCH._serialized_end=1118
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/console.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import console_base_pb2 as ydb_dot_core_dot_protos_dot_console__base__pb2
from ydb.core.protos import console_tenant_pb2 as ydb_dot_core_dot_protos_dot_console__tenant__pb2
from ydb.core.protos import console_config_pb2 as ydb_dot_core_dot_protos_dot_console__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dydb/core/protos/console.proto\x12\x0eNKikimrConsole\x1a\"ydb/core/protos/console_base.proto\x1a$ydb/core/protos/console_tenant.proto\x1a$ydb/core/protos/console_config.proto\"w\n\x07TConfig\x12\x35\n\rTenantsConfig\x18\x01 \x01(\x0b\x32\x1e.NKikimrConsole.TTenantsConfig\x12\x35\n\rConfigsConfig\x18\x02 \x01(\x0b\x32\x1e.NKikimrConsole.TConfigsConfig\"\x13\n\x11TGetConfigRequest\"=\n\x12TGetConfigResponse\x12\'\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TConfig\"\x82\x01\n\x11TSetConfigRequest\x12\'\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TConfig\x12\x44\n\x05Merge\x18\x02 \x01(\x0e\x32*.NKikimrConsole.TConfigItem.EMergeStrategy:\tOVERWRITE\"=\n\x12TSetConfigResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\"\xa7\x01\n\x0eTLogRecordData\x12\x31\n\x06\x41\x63tion\x18\x01 \x01(\x0b\x32!.NKikimrConsole.TConfigureRequest\x12K\n\x0f\x41\x66\x66\x65\x63tedConfigs\x18\x02 \x03(\x0b\x32\x32.NKikimrConsole.TConfigureResponse.TAffectedConfig\x12\x15\n\rAffectedKinds\x18\x03 \x03(\r\"g\n\nTLogRecord\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x11\n\tTimestamp\x18\x02 \x01(\x04\x12\x0c\n\x04User\x18\x03 \x01(\t\x12,\n\x04\x44\x61ta\x18\x04 \x01(\x0b\x32\x1e.NKikimrConsole.TLogRecordData\"\x94\x01\n\nTLogFilter\x12\x0e\n\x06\x46romId\x18\x01 \x01(\x04\x12\x15\n\rFromTimestamp\x18\x02 \x01(\x04\x12\x12\n\x05Limit\x18\x03 \x01(\r:\x03\x31\x30\x30\x12\x15\n\rAffectedKinds\x18\x04 \x03(\r\x12\r\n\x05Users\x18\x05 \x03(\t\x12\x14\n\x0c\x45xcludeUsers\x18\x06 \x03(\t\x12\x0f\n\x07Reverse\x18\x07 \x01(\x08\"C\n\x12TGetLogTailRequest\x12-\n\tLogFilter\x18\x01 \x01(\x0b\x32\x1a.NKikimrConsole.TLogFilter\"n\n\x13TGetLogTailResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12.\n\nLogRecords\x18\x04 \x03(\x0b\x32\x1a.NKikimrConsole.TLogRecordB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.console_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TCONFIG._serialized_start=161
  _TCONFIG._serialized_end=280
  _TGETCONFIGREQUEST._serialized_start=282
  _TGETCONFIGREQUEST._serialized_end=301
  _TGETCONFIGRESPONSE._serialized_start=303
  _TGETCONFIGRESPONSE._serialized_end=364
  _TSETCONFIGREQUEST._serialized_start=367
  _TSETCONFIGREQUEST._serialized_end=497
  _TSETCONFIGRESPONSE._serialized_start=499
  _TSETCONFIGRESPONSE._serialized_end=560
  _TLOGRECORDDATA._serialized_start=563
  _TLOGRECORDDATA._serialized_end=730
  _TLOGRECORD._serialized_start=732
  _TLOGRECORD._serialized_end=835
  _TLOGFILTER._serialized_start=838
  _TLOGFILTER._serialized_end=986
  _TGETLOGTAILREQUEST._serialized_start=988
  _TGETLOGTAILREQUEST._serialized_end=1055
  _TGETLOGTAILRESPONSE._serialized_start=1057
  _TGETLOGTAILRESPONSE._serialized_end=1167
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/mkql_proto/protos/minikql.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ydb/library/mkql_proto/protos/minikql.proto\x12\x0eNKikimrMiniKQL\x1a\x1cgoogle/protobuf/struct.proto\"2\n\x0eTDecimalParams\x12\x11\n\tPrecision\x18\x01 \x02(\r\x12\r\n\x05Scale\x18\x02 \x02(\r\"R\n\tTDataType\x12\x0e\n\x06Scheme\x18\x01 \x02(\r\x12\x35\n\rDecimalParams\x18\x02 \x01(\x0b\x32\x1e.NKikimrMiniKQL.TDecimalParams\"4\n\rTOptionalType\x12#\n\x04Item\x18\x01 \x02(\x0b\x32\x15.NKikimrMiniKQL.TType\"0\n\tTListType\x12#\n\x04Item\x18\x01 \x02(\x0b\x32\x15.NKikimrMiniKQL.TType\"4\n\nTTupleType\x12&\n\x07\x45lement\x18\x01 \x03(\x0b\x32\x15.NKikimrMiniKQL.TType\"<\n\x07TMember\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12#\n\x04Type\x18\x02 \x02(\x0b\x32\x15.NKikimrMiniKQL.TType\"6\n\x0bTStructType\x12\'\n\x06Member\x18\x01 \x03(\x0b\x32\x17.NKikimrMiniKQL.TMember\"|\n\x0cTVariantType\x12\x30\n\nTupleItems\x18\x01 \x01(\x0b\x32\x1a.NKikimrMiniKQL.TTupleTypeH\x00\x12\x32\n\x0bStructItems\x18\x02 \x01(\x0b\x32\x1b.NKikimrMiniKQL.TStructTypeH\x00\x42\x06\n\x04type\"W\n\tTDictType\x12\"\n\x03Key\x18\x01 \x02(\x0b\x32\x15.NKikimrMiniKQL.TType\x12&\n\x07Payload\x18\x02 \x02(\x0b\x32\x15.NKikimrMiniKQL.TType\"\x16\n\x07TPgType\x12\x0b\n\x03oid\x18\x01 \x02(\r\"?\n\x0bTTaggedType\x12\x0b\n\x03Tag\x18\x01 \x02(\t\x12#\n\x04Item\x18\x02 \x02(\x0b\x32\x15.NKikimrMiniKQL.TType\"\xd4\x03\n\x05TType\x12\'\n\x04Kind\x18\x01 \x02(\x0e\x32\x19.NKikimrMiniKQL.ETypeKind\x12)\n\x04\x44\x61ta\x18\x02 \x01(\x0b\x32\x19.NKikimrMiniKQL.TDataTypeH\x00\x12\x31\n\x08Optional\x18\x03 \x01(\x0b\x32\x1d.NKikimrMiniKQL.TOptionalTypeH\x00\x12)\n\x04List\x18\x04 \x01(\x0b\x32\x19.NKikimrMiniKQL.TListTypeH\x00\x12+\n\x05Tuple\x18\x05 \x01(\x0b\x32\x1a.NKikimrMiniKQL.TTupleTypeH\x00\x12-\n\x06Struct\x18\x06 \x01(\x0b\x32\x1b.NKikimrMiniKQL.TStructTypeH\x00\x12)\n\x04\x44ict\x18\x07 \x01(\x0b\x32\x19.NKikimrMiniKQL.TDictTypeH\x00\x12/\n\x07Variant\x18\x08 \x01(\x0b\x32\x1c.NKikimrMiniKQL.TVariantTypeH\x00\x12%\n\x02Pg\x18\t \x01(\x0b\x32\x17.NKikimrMiniKQL.TPgTypeH\x00\x12-\n\x06Tagged\x18\n \x01(\x0b\x32\x1b.NKikimrMiniKQL.TTaggedTypeH\x00\x42\x0b\n\ttype_type\"Z\n\nTValuePair\x12#\n\x03Key\x18\x01 \x02(\x0b\x32\x16.NKikimrMiniKQL.TValue\x12\'\n\x07Payload\x18\x02 \x02(\x0b\x32\x16.NKikimrMiniKQL.TValue\"\xe8\x03\n\x06TValue\x12\x0e\n\x04\x42ool\x18\x01 \x01(\x08H\x00\x12\x0f\n\x05Int32\x18\x02 \x01(\x05H\x00\x12\x10\n\x06Uint32\x18\x03 \x01(\rH\x00\x12\x0f\n\x05Int64\x18\x04 \x01(\x03H\x00\x12\x10\n\x06Uint64\x18\x05 \x01(\x04H\x00\x12\x0f\n\x05\x46loat\x18\x06 \x01(\x02H\x00\x12\x10\n\x06\x44ouble\x18\x07 \x01(\x01H\x00\x12\x0f\n\x05\x42ytes\x18\x08 \x01(\x0cH\x00\x12\x0e\n\x04Text\x18\t \x01(\tH\x00\x12*\n\x08Optional\x18\n \x01(\x0b\x32\x16.NKikimrMiniKQL.TValueH\x00\x12\x10\n\x06Low128\x18\x0f \x01(\x06H\x00\x12\x33\n\rNullFlagValue\x18\x12 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12$\n\x04List\x18\x0b \x03(\x0b\x32\x16.NKikimrMiniKQL.TValue\x12%\n\x05Tuple\x18\x0c \x03(\x0b\x32\x16.NKikimrMiniKQL.TValue\x12&\n\x06Struct\x18\r \x03(\x0b\x32\x16.NKikimrMiniKQL.TValue\x12(\n\x04\x44ict\x18\x0e \x03(\x0b\x32\x1a.NKikimrMiniKQL.TValuePair\x12\r\n\x05Hi128\x18\x10 \x01(\x06\x12\x14\n\x0cVariantIndex\x18\x11 \x01(\rB\r\n\x0bvalue_value\"U\n\x07TResult\x12#\n\x04Type\x18\x01 \x01(\x0b\x32\x15.NKikimrMiniKQL.TType\x12%\n\x05Value\x18\x02 \x01(\x0b\x32\x16.NKikimrMiniKQL.TValue\"U\n\x07TParams\x12#\n\x04Type\x18\x01 \x01(\x0b\x32\x15.NKikimrMiniKQL.TType\x12%\n\x05Value\x18\x02 \x01(\x0b\x32\x16.NKikimrMiniKQL.TValue*\xc3\x01\n\tETypeKind\x12\x0b\n\x07Unknown\x10\x00\x12\x08\n\x04Void\x10\x01\x12\x08\n\x04\x44\x61ta\x10\x02\x12\x0c\n\x08Optional\x10\x03\x12\x08\n\x04List\x10\x04\x12\t\n\x05Tuple\x10\x05\x12\n\n\x06Struct\x10\x06\x12\x08\n\x04\x44ict\x10\x07\x12\x0b\n\x07Variant\x10\x08\x12\x08\n\x04Null\x10\t\x12\x06\n\x02Pg\x10\n\x12\n\n\x06Tagged\x10\x0b\x12\x0f\n\x0bReserved_12\x10\x0c\x12\x0f\n\x0bReserved_13\x10\r\x12\x0f\n\x0bReserved_14\x10\x0e\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.mkql_proto.protos.minikql_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _ETYPEKIND._serialized_start=2038
  _ETYPEKIND._serialized_end=2233
  _TDECIMALPARAMS._serialized_start=93
  _TDECIMALPARAMS._serialized_end=143
  _TDATATYPE._serialized_start=145
  _TDATATYPE._serialized_end=227
  _TOPTIONALTYPE._serialized_start=229
  _TOPTIONALTYPE._serialized_end=281
  _TLISTTYPE._serialized_start=283
  _TLISTTYPE._serialized_end=331
  _TTUPLETYPE._serialized_start=333
  _TTUPLETYPE._serialized_end=385
  _TMEMBER._serialized_start=387
  _TMEMBER._serialized_end=447
  _TSTRUCTTYPE._serialized_start=449
  _TSTRUCTTYPE._serialized_end=503
  _TVARIANTTYPE._serialized_start=505
  _TVARIANTTYPE._serialized_end=629
  _TDICTTYPE._serialized_start=631
  _TDICTTYPE._serialized_end=718
  _TPGTYPE._serialized_start=720
  _TPGTYPE._serialized_end=742
  _TTAGGEDTYPE._serialized_start=744
  _TTAGGEDTYPE._serialized_end=807
  _TTYPE._serialized_start=810
  _TTYPE._serialized_end=1278
  _TVALUEPAIR._serialized_start=1280
  _TVALUEPAIR._serialized_end=1370
  _TVALUE._serialized_start=1373
  _TVALUE._serialized_end=1861
  _TRESULT._serialized_start=1863
  _TRESULT._serialized_end=1948
  _TPARAMS._serialized_start=1950
  _TPARAMS._serialized_end=2035
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/dq/actors/protos/dq_status_codes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6ydb/library/yql/dq/actors/protos/dq_status_codes.proto\x12\rNYql.NDqProto\"\xa3\x02\n\tStatusIds\"\x95\x02\n\nStatusCode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x0b\n\x07\x41\x42ORTED\x10\x04\x12\x0f\n\x0bUNAVAILABLE\x10\x05\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x06\x12\x17\n\x13PRECONDITION_FAILED\x10\x07\x12\r\n\tCANCELLED\x10\x08\x12\x0e\n\nOVERLOADED\x10\t\x12\x12\n\x0eLIMIT_EXCEEDED\x10\n\x12\x0f\n\x0bUNSUPPORTED\x10\x0b\x12\x12\n\x0e\x45XTERNAL_ERROR\x10\x0c\x12\x16\n\x12\x43LUSTER_OVERLOADED\x10\r\x12\x10\n\x0cSCHEME_ERROR\x10\x0e\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.dq.actors.protos.dq_status_codes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STATUSIDS._serialized_start=74
  _STATUSIDS._serialized_end=365
  _STATUSIDS_STATUSCODE._serialized_start=88
  _STATUSIDS_STATUSCODE._serialized_end=365
# @@protoc_insertion_point(module_scope)
